/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it
 * is applied to this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * AgroSense. If not, see <http://www.gnu.org/licenses/>.
 */
package eu.agrosense.client.field.soilsample;

import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.sensor.ObservationNodeProvider;
import nl.cloudfarming.client.sensor.visual.NewObservationAction;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;

/**
 * Action to create a new soil sample
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages("NewSoilSampleAction_name=New soil sample")
@ActionID(category = "Field", id = "nl.cloudfarming.client.field.type.wizard.NewSoilSampleAction")
@ActionRegistration(displayName = "#NewSoilSampleAction_name", lazy=true)
@ActionReferences({
    @ActionReference(path = "Loaders/application/x-agrosense-field/Actions", position = 1500),
    @ActionReference(path = ObservationNodeProvider.ACTION_PATH, position = 1500)
})
public class NewSoilSampleAction extends NewObservationAction{

    private static final String ICON = "eu/agrosense/client/field/soilsample/flask32.png";
    private Field field;
    
    public NewSoilSampleAction() {
        super(ICON, Bundle.NewSoilSampleAction_name());
    }

    @Override
    protected boolean enable(Node[] activatedNodes) {
        if(activatedNodes.length == 1){
            Node activeNode = activatedNodes[0];
            field = activeNode.getLookup().lookup(Field.class);
            return field != null && field.getGeometry() != null;
        }
        return false;
    }

    @Override
    protected void performAction(Node[] activatedNodes) {
        super.performAction(field.getGeometry(), field.getURI());
    }

    
}